Count
=====

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: Count
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Count.binarize
      ~Count.closed_expectation
      ~Count.closed_variance
      ~Count.increasing
      ~Count.key
      ~Count.name
      ~Count.needs_candidates
      ~Count.supported_rank_types
      ~Count.supports_weights
      ~Count.synonyms
      ~Count.value_range

   .. rubric:: Methods Summary

   .. autosummary::

      ~Count.__call__
      ~Count.expected_value
      ~Count.extra_repr
      ~Count.get_description
      ~Count.get_link
      ~Count.get_range
      ~Count.get_sampled_values
      ~Count.iter_extra_repr
      ~Count.numeric_expected_value
      ~Count.numeric_expected_value_with_ci
      ~Count.numeric_variance
      ~Count.numeric_variance_with_ci
      ~Count.std
      ~Count.variance

   .. rubric:: Attributes Documentation

   .. autoattribute:: binarize
   .. autoattribute:: closed_expectation
   .. autoattribute:: closed_variance
   .. autoattribute:: increasing
   .. autoattribute:: key
   .. autoattribute:: name
   .. autoattribute:: needs_candidates
   .. autoattribute:: supported_rank_types
   .. autoattribute:: supports_weights
   .. autoattribute:: synonyms
   .. autoattribute:: value_range

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: expected_value
   .. automethod:: extra_repr
   .. automethod:: get_description
   .. automethod:: get_link
   .. automethod:: get_range
   .. automethod:: get_sampled_values
   .. automethod:: iter_extra_repr
   .. automethod:: numeric_expected_value
   .. automethod:: numeric_expected_value_with_ci
   .. automethod:: numeric_variance
   .. automethod:: numeric_variance_with_ci
   .. automethod:: std
   .. automethod:: variance
